@@ -24,68 +24,116 @@ sub import {
     }
 }
 
+# TODO: Help in English
+
 1;
 __END__
 
 =pod
 =cut
-sub help_virtualHosts_en {
-    print <<EOT;
-<h3>Virtual Hosts</h3>
-This help chapter does not exist in english. If you want to help us, you can
-edit lib/Lemonldap/NG/Manager/Help.pm in lemonldap-ng source tree and send us
-your contribution.<br>
-Thanks.
-EOT
-}
-
-sub help_macros_en {
-    print <<EOT;
-<h3>Macros</h3>
-This help chapter does not exist in english. If you want to help us, you can
-edit lib/Lemonldap/NG/Manager/Help.pm in lemonldap-ng source tree and send us
-your contribution.<br>
-Thanks.
-EOT
-}
-
 sub help_groups_en {
     print <<EOT;
 <h3>User Groups</h3>
-This help chapter does not exist in english. If you want to help us, you can
-edit lib/Lemonldap/NG/Manager/Help.pm in lemonldap-ng source tree and send us
-your contribution.<br>
-Thanks.
+<p> Groups are not required but accelerate the treatment of the requests. For
+example, if a virtual host is granted only for 3 users, the rule is&nbsp;:</p>
+<pre>
+    # test.example.com - Rules
+    default =&gt; \$uid eq "user1" or \$uid eq "user2" or \$uid eq "user3"
+</pre>
+<p> The problem is that this rule is calculated for each HTTP request. Other
+example, if 2 sites have the same rules, any modification on one has to be
+write in the second. The 'groups' system solve this&nbsp;: groups are
+evaluated one time in the authentication phase, and the result is stored in the
+\$groups variable. The rule abode becomes&nbsp;:</p> 
+<pre>
+    # Group declaration
+    group1 =&gt; \$uid eq "user1" or \$uid eq "user2" or \$uid eq "user3"
+
+    # Use of the group :
+    # test.example.com - Rules
+    default =&gt; \$groups =~ /\\bgroup1\\b/
+</pre>
+<p> The last rule is a Perl regular expression (PCRE) that means 'search the
+word "group1" in the string "groups"'.</p>
+<p> The \$groups string joins all the groups where the user matchs the
+expression. The groups are separated by a space in the \$groups string.
 EOT
 }
 
-sub help_ldap_en {
+sub help_groups_fr {
     print <<EOT;
-<h3>LDAP Parameters</h3>
-This help chapter does not exist in english. If you want to help us, you can
-edit lib/Lemonldap/NG/Manager/Help.pm in lemonldap-ng source tree and send us
-your contribution.<br>
-Thanks.
+<h3>Groupes d'utilisateurs</h3>
+<p>Les groupes ne sont pas indispensables mais acc&eacute;l&egrave;rent le traitement des
+requ&ecirc;tes. Par exemple, si un h&ocirc;te virtuel est autoris&eacute; nominativement &agrave;
+user, user2 et user3, la r&egrave;gle d'acc&egrave;s s'&eacute;crira&nbsp;:</p>
+<pre>
+    # test.example.com - R&egrave;gles
+    default =&gt; \$uid eq "user1" or \$uid eq "user2" or \$uid eq "user3"
+</pre>
+<p> Le probl&egrave;me est que cette expression sera calcul&eacute;e &agrave; chaque requ&ecirc;te HTTP.
+D'autre part, si 2 h&ocirc;tes virtuels ont la m&ecirc;me r&egrave;gle d'acc&egrave;s, toute modification
+doit &ecirc;tre r&eacute;percut&eacute;e sur les deux h&ocirc;tes virtuels. Le syst&egrave;me des groupes permet
+de r&eacute;soudre ces deux probl&egrave;mes&nbsp;: lors de la connexion au portail, les
+expressions complexes sont calcul&eacute;es une fois pour toute la session et le
+r&eacute;sultat est stock&eacute; dans la cha&icirc;ne \$groups. L'exemple pr&eacute;c&eacute;dent devient
+alors&nbsp;:</p>
+<pre>
+    # D&eacute;claration d'un groupe
+    group1 =&gt; \$uid eq "user1" or \$uid eq "user2" or \$uid eq "user3"
+
+    # Utilisation :
+    # test.example.com - R&egrave;gles
+    default =&gt; \$groups =~ /\\bgroup1\\b/
+</pre>
+<p> Cette derni&egrave;re expression est une expression r&eacute;guli&egrave;re Perl (PCRE) qui
+correspond &agrave; la recherche du mot group1 dans la cha&icirc;ne \$groups (\\b signifie
+d&eacute;but ou fin de mot).</p>
+
+<p>La variable export&eacute;e \$groups est une cha&icirc;ne de caract&egrave;res compos&eacute;s de tous les
+noms de groupes auquel l'utilisateur connect&eacute; appartient (c'est &agrave; dire les
+noms de groupe pour lesquels l'expression est vraie.</p>
 EOT
 }
 
 sub help_vars_en {
     print <<EOT;
 <h3>Variables (LDAP attributes)</h3>
-This help chapter does not exist in english. If you want to help us, you can
-edit lib/Lemonldap/NG/Manager/Help.pm in lemonldap-ng source tree and send us
-your contribution.<br>
-Thanks.
+<p> Set here the LDAP attributes you need in your configuration or in exported
+headers.</p>
+<p> Declare as the following&nbsp;:</p>
+<pre>  &lt;MyName&gt; =&gt; &lt;real LDAP attribute name&gt;</pre>
+<p>Examples :</p>
+<pre>
+  uid   =&gt; uid
+  unit  =&gt; ou
+</pre>
+Declared names can be used in rules, groups, macros and HTTP headers by using
+them with '\$'. Example&nbsp;:
+<pre>
+  group1 =&gt; \$uid eq 'user1' or \$uid eq 'user2'
+</pre>
 EOT
 }
 
-sub help_storage_en {
+sub help_vars_fr {
     print <<EOT;
-<h3>Sessions Storage</h3>
-This help chapter does not exist in english. If you want to help us, you can
-edit lib/Lemonldap/NG/Manager/Help.pm in lemonldap-ng source tree and send us
-your contribution.<br>
-Thanks.
+<h3>Variables (attributs LDAP)</h3>
+<p> Indiquez ici tous les attributs LDAP dont vous avez besoin dans votre
+configuration (pour d&eacute;finir les groupes, les macros, les r&egrave;gles
+d'acc&egrave;s aux h&ocirc;tes virtuels ou encore les en-t&ecirc;tes HTTP).</p>
+<p>La d&eacute;claration d'une variable se fait sous la forme&nbsp;:</p>
+<pre>  &lt;nom declare&gt; =&gt; &lt;nom de l'attribut LDAP&gt;</pre>
+<p>Exemples :</p>
+<pre>
+  uid  =&gt; uid
+  unite  =&gt; ou
+</pre>
+Les noms d&eacute;clar&eacute;s s'utilisent ensuite dans les r&egrave;gles, les
+groupes, les macros ou les en-t&ecirc;tes HTTP en les faisant
+pr&eacute;c&eacute;der du signe '\$'. Exemple&nbsp;:
+<pre>
+  group1 =&gt; \$uid eq 'user1' or \$uid eq 'user2'
+</pre>
 EOT
 }
 
@@ -99,13 +147,25 @@ Thanks.
 EOT
 }
 
-sub help_cookieName_en {
+sub help_authParams_fr {
     print <<EOT;
-<h3>Cookie Name</h3>
-This help chapter does not exist in english. If you want to help us, you can
-edit lib/Lemonldap/NG/Manager/Help.pm in lemonldap-ng source tree and send us
-your contribution.<br>
-Thanks.
+<h3>Param&egrave;tres d'authentification</h3>
+<dl>
+<dt> Type d'authentfication </dt>
+<dd> Le sch&eacute;ma classique d'authentification Lemonldap consiste &agrave; utiliser une
+authentification par LDAP. Vous pouvez changer ceci en ssl par exemple.</dd>
+
+<dt> Portail </dt>
+<dd> Indiquez ici l'URL ou seront renvoy&eacute;s les utilisateurs non authentifi&eacute;s.
+Cette URL doit bien sur correspondre &agrave; un portail utilisant
+Lemonldap::NG::Portal::SharedConf.</dd>
+
+<dt> Cookie s&eacute;curis&eacute; (SSL) </dt>
+<dd> Une fois authentifi&eacute;, l'utilisateur est reconnu par son cookie. Si tous
+les h&ocirc;tes virtuels de votre domaine son prot&eacute;g&eacute;s par SSL, mettez cette option
+&agrave; 1, ainsi le cookie ne sera pr&eacute;sent&eacute; par le navigateur qu'aux sites prot&eacute;g&eacute;s,
+ce qui &eacute;vite un vol de session.
+</dl>
 EOT
 }
 
@@ -119,6 +179,61 @@ Thanks.
 EOT
 }
 
+sub help_domain_fr {
+    print <<EOT;
+<h3>Domaine protg</h3>
+<p> Indiquez ici le nom du domaine (ou du sous-domaine) contenant vos
+applications  protger.<br>
+ATTENTION : tous les htes virtuels protgs ainsi que le portail
+d'authentification doivent se trouver dans ce domaine.
+EOT
+}
+
+sub help_virtualHosts_en {
+    print <<EOT;
+<h3>Virtual Hosts</h3>
+
+<p> A virtual host configuration is cutted in 2 pieces&nbsp;: the rules and the HTTP
+headers.</p>
+
+<p> <u>Note</u> : If portal and handlers are not in the same domain than declared
+in "General Parameters" menu, <u>you have to use</u> CDA modules. Else, session
+cookie is not seen by handlers.
+
+<h4> Rules </h4>
+
+<p> A rule associates a regular expression with a perl boolean expression.
+When a user tries to access to an URL that match with the regular expression,
+access is granted or not depending on the boolean expression result&nbsp;:</p>
+
+<pre>
+  # Virtual host test.example.com - rules
+  ^/protected =&gt; \$groups =~ /\\bgroup1\\b/
+</pre>
+
+<p> This rule means that all URL starting with '/protected', are reserved to
+users member of 'group1'. You can also use 'accept' and 'deny' keywords.
+'accept' keyword means that all authenticated users are granted.</p>
+
+<p> If URL doesn't match any regular expression, 'default' rule is called to
+grant or not.</p>
+
+<h4> Headers </h4>
+
+<p> Headers are used to inform the remote application on the connected user.
+They are declared as&nbsp;:
+<tt>&lt;Header Name&gt;&nbsp;=&gt;&nbsp;&lt;Perl expression&gt;.
+</p>
+
+<p> Examples :</p>
+
+<pre>
+  Auth-User =&gt; \$uid
+  Unite     =&gt; \$departmentUID
+</pre>
+EOT
+}
+
 sub help_virtualHosts_fr {
     print <<EOT;
 <h3>H&ocirc;tes virtuels</h3>
@@ -128,7 +243,8 @@ r&egrave;gles et les en-t&ecirc;tes HTTP export&eacute;s.</p>
 
 <p> <u>Note</u> : pour que le m&eacute;canisme d'authentification fonctionne, tous
 les h&ocirc;tes virtuels et le portail doivent se trouver dans le domaine d&eacute;clar&eacute;
-dans les param&egrave;tres g&eacute;n&eacute;raux.</p>
+dans les param&egrave;tres g&eacute;n&eacute;raux ou <u>utiliser les modules CDA</u>
+<i>(Cross-Domain-Authentication)</i> qui gre la transmission de l'identifiant.</p>
 
 <h4> R&egrave;gles</h4>
 
@@ -165,12 +281,33 @@ comme suit&nbsp;: <tt>&lt;nom de l'en-t&ecirc;te&gt; =&gt; &lt;expression Perl&g
 EOT
 }
 
+sub help_macros_en {
+    print <<EOT;
+<h3>Macros</h3>
+<p> Macros are used to add new variables to user variables attributes). Those
+new variables are calculated from other variables issued from LDAP attributes.
+This mechanism avoid to do more than one time the same operation in the
+authentication phase. Example&nbsp;:</p>
+<pre>
+    # macros
+    long_name => \$givenname . " " . \$surname
+    admin     => \$uid eq "foo" or \$uid eq "bar"
+    
+    # test.example.com - Headers
+    Name      => \$long_name
+    
+    # test.example.com - Rules
+    ^/admin/ => \$admin
+EOT
+}
+
 sub help_macros_fr {
     print <<EOT;
 <h3>Macros</h3>
-<p> Les macros permettent d'ajouter des variables calcul&eacute;es &agrave; partir des
-attributs LDAP (variables export&eacute;es). Elles &eacute;vitent de r&eacute;p&eacute;ter le m&ecirc;me calcul
-plusieurs fois dans la configuration. Exemple&nbsp;:</p>
+<p> Les macros permettent d'ajouter des variables calcul&eacute;es &agrave;
+partir des attributs LDAP (variables export&eacute;es). Elles &eacute;vitent
+de r&eacute;p&eacute;ter le m&ecirc;me calcul plusieurs fois dans la phase
+d'authentification. Exemple&nbsp;:</p>
 <pre>
     # macros
     nom_complet => \$givenname . " " . \$surname
@@ -184,38 +321,13 @@ plusieurs fois dans la configuration. Exemple&nbsp;:</p>
 EOT
 }
 
-sub help_groups_fr {
+sub help_ldap_en {
     print <<EOT;
-<h3>Groupes d'utilisateurs</h3>
-<p>Les groupes ne sont pas indispensables mais acc&eacute;l&egrave;rent le traitement des
-requ&ecirc;tes. Par exemple, si un h&ocirc;te virtuel est autoris&eacute; nominativement &agrave;
-user, user2 et user3, la r&egrave;gle d'acc&egrave;s s'&eacute;crira&nbsp;:</p>
-<pre>
-    # test.example.com - R&egrave;gles
-    default =&gt; \$uid eq "user1" or \$uid eq "user2" or \$uid eq "user3"
-</pre>
-<p> Le probl&egrave;me est que cette expression sera calcul&eacute;e &agrave; chaque requ&ecirc;te HTTP.
-D'autre part, si 2 h&ocirc;tes virtuels ont la m&ecirc;me r&egrave;gle d'acc&egrave;s, toute modification
-doit &ecirc;tre r&eacute;percut&eacute;e sur les deux h&ocirc;tes virtuels. Le syst&egrave;me des groupes permet
-de r&eacute;soudre ces deux probl&egrave;mes&nbsp;: lors de la connexion au portail, les
-expressions complexes sont calcul&eacute;es une fois pour toute la session et le
-r&eacute;sultat est stock&eacute; dans la cha&icirc;ne \$groups. L'exemple pr&eacute;c&eacute;dent devient
-alors&nbsp;:</p>
-<pre>
-    # D&eacute;claration d'un groupe (on suppose ici que ou est un champ mono-valu&eacute;)
-    group1 =&gt; \$uid eq "user1" or \$uid eq "user2" or \$uid eq "user3"
-
-    # Utilisation :
-    # test.example.com - R&egrave;gles
-    default =&gt; \$groups =~ /\\bgroup1\\b/
-</pre>
-<p> Cette derni&egrave;re expression est une expression r&eacute;guli&egrave;re Perl (PCRE) qui
-correspond &agrave; la recherche du mot group1 dans la cha&icirc;ne \$groups (\\b signifie
-d&eacute;but ou fin de mot).</p>
-
-<p>La variable export&eacute;e \$groups est une cha&icirc;ne de caract&egrave;res compos&eacute;s de tous les
-noms de groupes auquel l'utilisateur connect&eacute; appartient (c'est &agrave; dire les
-noms de groupe pour lesquels l'expression est vraie.</p>
+<h3>LDAP Parameters</h3>
+This help chapter does not exist in english. If you want to help us, you can
+edit lib/Lemonldap/NG/Manager/Help.pm in lemonldap-ng source tree and send us
+your contribution.<br>
+Thanks.
 EOT
 }
 
@@ -240,23 +352,13 @@ exemple).</p>
 EOT
 }
 
-sub help_vars_fr {
+sub help_storage_en {
     print <<EOT;
-<h3>Variables (attributs LDAP)</h3>
-<p> Indiquez ici tous les attributs LDAP dont vous avez besoin dans votre
-configuration (pour d&eacute;finir les groupes, les r&egrave;gles d'acc&egrave;s au h&ocirc;tes virtuels
-ou encore les en-t&ecirc;tes HTTP).</p>
-<p>La d&eacute;claration d'une variable se fait sous la forme&nbsp;:</p>
-<pre>  &lt;nom declare&gt; =&gt; &lt;nom de l'attribut LDAP&gt;</pre>
-<p>Exemples :</p>
-<pre>
-  uid  =&gt; uid
-  unite  =&gt; ou
-</pre>
-Les noms d&eacute;clar&eacute;s s'utilisent ensuite dans les r&egrave;gles, les groupes ou les
-en-t&ecirc;tes HTTP en les faisant pr&eacute;c&eacute;der du signe '\$'. Exemple&nbsp;:
-<pre>
-  group1 =&gt; \$uid eq 'user1' or \$uid eq 'user2'
+<h3>Sessions Storage</h3>
+This help chapter does not exist in english. If you want to help us, you can
+edit lib/Lemonldap/NG/Manager/Help.pm in lemonldap-ng source tree and send us
+your contribution.<br>
+Thanks.
 EOT
 }
 
@@ -284,25 +386,13 @@ indiquer les param&egrave;tres correspondants &agrave; ce module&nbsp;:</p>
 EOT
 }
 
-sub help_authParams_fr {
+sub help_cookieName_en {
     print <<EOT;
-<h3>Param&egrave;tres d'authentification</h3>
-<dl>
-<dt> Type d'authentfication </dt>
-<dd> Le sch&eacute;ma classique d'authentification Lemonldap consiste &agrave; utiliser une
-authentification par LDAP. Vous pouvez changer ceci en ssl par exemple.</dd>
-
-<dt> Portail </dt>
-<dd> Indiquez ici l'URL ou seront renvoy&eacute;s les utilisateurs non authentifi&eacute;s.
-Cette URL doit bien sur correspondre &agrave; un portail utilisant
-Lemonldap::NG::Portal::SharedConf.</dd>
-
-<dt> Cookie s&eacute;curis&eacute; (SSL) </dt>
-<dd> Une fois authentifi&eacute;, l'utilisateur est reconnu par son cookie. Si tous
-les h&ocirc;tes virtuels de votre domaine son prot&eacute;g&eacute;s par SSL, mettez cette option
-&agrave; 1, ainsi le cookie ne sera pr&eacute;sent&eacute; par le navigateur qu'aux sites prot&eacute;g&eacute;s,
-ce qui &eacute;vite un vol de session.
-</dl>
+<h3>Cookie Name</h3>
+This help chapter does not exist in english. If you want to help us, you can
+edit lib/Lemonldap/NG/Manager/Help.pm in lemonldap-ng source tree and send us
+your contribution.<br>
+Thanks.
 EOT
 }
 
@@ -315,13 +405,3 @@ ATTENTION, tout changement ncessite le redmarrage de tous les serveurs Apache
 hbergeant des agents de protection Lemonldap::NG::Handler.</p>
 EOT
 }
-
-sub help_domain_fr {
-    print <<EOT;
-<h3>Domaine protg</h3>
-<p> Indiquez ici le nom du domaine (ou du sous-domaine) contenant vos
-applications  protger.<br>
-ATTENTION : tous les htes virtuels protgs ainsi que le portail
-d'authentification doivent se trouver dans ce domaine.
-EOT
-}
